system_theme library
Classes
- SystemAccentColor
- Defines accent colors & its variants. Colors are cached by default, call SystemAccentColor.load to update the colors.
- SystemTheme
- Class to return current system theme state on Windows.
- SystemThemeBuilder
- A widget that rebuilds when the system theme changes.
Extensions
Typedefs
- ThemeWidgetBuilder = Widget Function(BuildContext context, SystemAccentColor accent)