SystemTheme class

Class to return current system theme state on Windows.

accentColor returns the current accent color as a SystemAccentColor.

To configure a fallback color if accentColor is not available, set fallbackColor to the desired color

onChange returns a stream of SystemAccentColor that notifies when the system accent color changes.

Constructors

SystemTheme()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

accentColor → SystemAccentColor
Get the system accent color.
final
autoAdjustLightness ↔ bool
Whether to automatically adjust lightness if the color if the platform doesn't support it natively.
getter/setter pair
fallbackColor ↔ Color
The fallback color
getter/setter pair
onChange → Stream<SystemAccentColor>
A stream of SystemAccentColor that notifies when the system accent color changes.
no setter

Constants

getSystemAccentColorMethodName → const String
kDefaultFallbackColor → const Color
Default system accent color.